package javax.swing.plaf.basic;

import java.awt.event.HierarchyEvent;
import java.beans.PropertyChangeEvent;
import java.awt.event.HierarchyListener;
import java.beans.PropertyChangeListener;
import javax.swing.event.ChangeEvent;
import java.awt.event.ActionEvent;
import javax.swing.Timer;
import java.awt.event.ActionListener;
import javax.swing.SwingUtilities;
import java.awt.Point;
import sun.swing.SwingUtilities2;
import java.awt.geom.AffineTransform;
import java.awt.BasicStroke;
import java.awt.Graphics2D;
import java.awt.Graphics;
import javax.swing.BoundedRangeModel;
import sun.swing.DefaultLookup;
import java.awt.Dimension;
import java.awt.Component;
import java.awt.Insets;
import java.awt.FontMetrics;
import javax.swing.UIManager;
import javax.swing.LookAndFeel;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Rectangle;
import javax.swing.event.ChangeListener;
import javax.swing.JProgressBar;
import java.awt.Color;
import javax.swing.plaf.ProgressBarUI;

public class BasicProgressBarUI extends ProgressBarUI
{
    private int cachedPercent;
    private int cellLength;
    private int cellSpacing;
    private Color selectionForeground;
    private Color selectionBackground;
    private BasicProgressBarUI.Animator animator;
    protected JProgressBar progressBar;
    protected ChangeListener changeListener;
    private BasicProgressBarUI.Handler handler;
    private int animationIndex;
    private int numFrames;
    private int repaintInterval;
    private int cycleTime;
    private static boolean ADJUSTTIMER;
    protected Rectangle boxRect;
    private Rectangle nextPaintRect;
    private Rectangle componentInnards;
    private Rectangle oldComponentInnards;
    private double delta;
    private int maxPosition;
    
    public BasicProgressBarUI() {
        this.animationIndex = 0;
        this.delta = 0.0;
        this.maxPosition = 0;
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new BasicProgressBarUI();
    }
    
    @Override
    public void installUI(JComponent component) {
        this.progressBar = (JProgressBar)component;
        this.installDefaults();
        this.installListeners();
        if (this.progressBar.isIndeterminate()) {
            this.initIndeterminateValues();
        }
    }
    
    @Override
    public void uninstallUI(JComponent component) {
        if (this.progressBar.isIndeterminate()) {
            this.cleanUpIndeterminateValues();
        }
        this.uninstallDefaults();
        this.uninstallListeners();
        this.progressBar = null;
    }
    
    protected void installDefaults() {
        LookAndFeel.installProperty(this.progressBar, "opaque", Boolean.TRUE);
        LookAndFeel.installBorder(this.progressBar, "ProgressBar.border");
        LookAndFeel.installColorsAndFont(this.progressBar, "ProgressBar.background", "ProgressBar.foreground", "ProgressBar.font");
        this.cellLength = UIManager.getInt("ProgressBar.cellLength");
        if (this.cellLength == 0) {
            this.cellLength = 1;
        }
        this.cellSpacing = UIManager.getInt("ProgressBar.cellSpacing");
        this.selectionForeground = UIManager.getColor("ProgressBar.selectionForeground");
        this.selectionBackground = UIManager.getColor("ProgressBar.selectionBackground");
    }
    
    protected void uninstallDefaults() {
        LookAndFeel.uninstallBorder(this.progressBar);
    }
    
    protected void installListeners() {
        this.changeListener = this.getHandler();
        this.progressBar.addChangeListener(this.changeListener);
        this.progressBar.addPropertyChangeListener(this.getHandler());
    }
    
    private BasicProgressBarUI.Handler getHandler() {
        if (this.handler == null) {
            this.handler = new BasicProgressBarUI.Handler();
        }
        return this.handler;
    }
    
    protected void startAnimationTimer() {
        if (this.animator == null) {
            this.animator = new BasicProgressBarUI.Animator();
        }
        BasicProgressBarUI.Animator.access$200(this.animator, this.getRepaintInterval());
    }
    
    protected void stopAnimationTimer() {
        if (this.animator != null) {
            BasicProgressBarUI.Animator.access$300(this.animator);
        }
    }
    
    protected void uninstallListeners() {
        this.progressBar.removeChangeListener(this.changeListener);
        this.progressBar.removePropertyChangeListener(this.getHandler());
        this.handler = null;
    }
    
    @Override
    public int getBaseline(JComponent c, int width, int height) {
        super.getBaseline(c, width, height);
        if (this.progressBar.isStringPainted() && this.progressBar.getOrientation() == 0) {
            FontMetrics fontMetrics = this.progressBar.getFontMetrics(this.progressBar.getFont());
            Insets insets = this.progressBar.getInsets();
            int top = insets.top;
            height = height - insets.top - insets.bottom;
            return top + (height + fontMetrics.getAscent() - fontMetrics.getLeading() - fontMetrics.getDescent()) / 2;
        }
        return -1;
    }
    
    @Override
    public Component.BaselineResizeBehavior getBaselineResizeBehavior(JComponent c) {
        super.getBaselineResizeBehavior(c);
        if (this.progressBar.isStringPainted() && this.progressBar.getOrientation() == 0) {
            return Component.BaselineResizeBehavior.CENTER_OFFSET;
        }
        return Component.BaselineResizeBehavior.OTHER;
    }
    
    protected Dimension getPreferredInnerHorizontal() {
        Dimension dimension = (Dimension)DefaultLookup.get(this.progressBar, this, "ProgressBar.horizontalSize");
        if (dimension == null) {
            dimension = new Dimension(146, 12);
            return dimension;
        }
        return dimension;
    }
    
    protected Dimension getPreferredInnerVertical() {
        Dimension dimension = (Dimension)DefaultLookup.get(this.progressBar, this, "ProgressBar.verticalSize");
        if (dimension == null) {
            dimension = new Dimension(12, 146);
            return dimension;
        }
        return dimension;
    }
    
    protected Color getSelectionForeground() {
        return this.selectionForeground;
    }
    
    protected Color getSelectionBackground() {
        return this.selectionBackground;
    }
    
    private int getCachedPercent() {
        return this.cachedPercent;
    }
    
    private void setCachedPercent(int cachedPercent) {
        this.cachedPercent = cachedPercent;
    }
    
    protected int getCellLength() {
        if (this.progressBar.isStringPainted()) {
            return 1;
        }
        return this.cellLength;
    }
    
    protected void setCellLength(int cellLength) {
        this.cellLength = cellLength;
    }
    
    protected int getCellSpacing() {
        if (this.progressBar.isStringPainted()) {
            return 0;
        }
        return this.cellSpacing;
    }
    
    protected void setCellSpacing(int cellSpacing) {
        this.cellSpacing = cellSpacing;
    }
    
    protected int getAmountFull(Insets insets, int n, int n2) {
        int n3 = 0;
        BoundedRangeModel model = this.progressBar.getModel();
        if (model.getMaximum() - model.getMinimum() != 0) {
            if (this.progressBar.getOrientation() == 0) {
                n3 = (int)Math.round((double)n * this.progressBar.getPercentComplete());
            }
            else {
                n3 = (int)Math.round((double)n2 * this.progressBar.getPercentComplete());
            }
        }
        return n3;
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        if (this.progressBar.isIndeterminate()) {
            this.paintIndeterminate(graphics, component);
        }
        else {
            this.paintDeterminate(graphics, component);
        }
    }
    
    protected Rectangle getBox(Rectangle genericBox) {
        int animationIndex = this.getAnimationIndex();
        int n = this.numFrames / 2;
        if (this.sizeChanged() || this.delta == 0.0 || (double)this.maxPosition == 0.0) {
            this.updateSizes();
        }
        genericBox = this.getGenericBox(genericBox);
        if (genericBox == null) {
            return null;
        }
        if (n <= 0) {
            return null;
        }
        if (this.progressBar.getOrientation() == 0) {
            if (animationIndex < n) {
                genericBox.x = this.componentInnards.x + (int)Math.round(this.delta * (double)animationIndex);
            }
            else {
                genericBox.x = this.maxPosition - (int)Math.round(this.delta * (double)(animationIndex - n));
            }
        }
        else if (animationIndex < n) {
            genericBox.y = this.componentInnards.y + (int)Math.round(this.delta * (double)animationIndex);
        }
        else {
            genericBox.y = this.maxPosition - (int)Math.round(this.delta * (double)(animationIndex - n));
        }
        return genericBox;
    }
    
    private void updateSizes() {
        if (this.progressBar.getOrientation() == 0) {
            this.maxPosition = this.componentInnards.x + this.componentInnards.width - this.getBoxLength(this.componentInnards.width, this.componentInnards.height);
        }
        else {
            this.maxPosition = this.componentInnards.y + this.componentInnards.height - this.getBoxLength(this.componentInnards.height, this.componentInnards.width);
        }
        this.delta = 2.0 * (double)this.maxPosition / (double)this.numFrames;
    }
    
    private Rectangle getGenericBox(Rectangle rectangle) {
        if (rectangle == null) {
            rectangle = new Rectangle();
        }
        if (this.progressBar.getOrientation() == 0) {
            rectangle.width = this.getBoxLength(this.componentInnards.width, this.componentInnards.height);
            if (rectangle.width < 0) {
                rectangle = null;
            }
            else {
                rectangle.height = this.componentInnards.height;
                rectangle.y = this.componentInnards.y;
            }
        }
        else {
            rectangle.height = this.getBoxLength(this.componentInnards.height, this.componentInnards.width);
            if (rectangle.height < 0) {
                rectangle = null;
            }
            else {
                rectangle.width = this.componentInnards.width;
                rectangle.x = this.componentInnards.x;
            }
        }
        return rectangle;
    }
    
    protected int getBoxLength(int n, int n2) {
        return (int)Math.round((double)n / 6.0);
    }
    
    protected void paintIndeterminate(Graphics graphics, JComponent component) {
        if (!(graphics instanceof Graphics2D)) {
            return;
        }
        Insets insets = this.progressBar.getInsets();
        int n = this.progressBar.getWidth() - (insets.right + insets.left);
        int n2 = this.progressBar.getHeight() - (insets.top + insets.bottom);
        if (n <= 0 || n2 <= 0) {
            return;
        }
        Graphics2D graphics2D = (Graphics2D)graphics;
        this.boxRect = this.getBox(this.boxRect);
        if (this.boxRect != null) {
            graphics2D.setColor(this.progressBar.getForeground());
            graphics2D.fillRect(this.boxRect.x, this.boxRect.y, this.boxRect.width, this.boxRect.height);
        }
        if (this.progressBar.isStringPainted()) {
            if (this.progressBar.getOrientation() == 0) {
                this.paintString(graphics2D, insets.left, insets.top, n, n2, this.boxRect.x, this.boxRect.width, insets);
            }
            else {
                this.paintString(graphics2D, insets.left, insets.top, n, n2, this.boxRect.y, this.boxRect.height, insets);
            }
        }
        return;
    }
    
    protected void paintDeterminate(Graphics graphics, JComponent component) {
        if (!(graphics instanceof Graphics2D)) {
            return;
        }
        Insets insets = this.progressBar.getInsets();
        int n = this.progressBar.getWidth() - (insets.right + insets.left);
        int n2 = this.progressBar.getHeight() - (insets.top + insets.bottom);
        if (n <= 0 || n2 <= 0) {
            return;
        }
        int cellLength = this.getCellLength();
        int cellSpacing = this.getCellSpacing();
        int amountFull = this.getAmountFull(insets, n, n2);
        Graphics2D graphics2D = (Graphics2D)graphics;
        graphics2D.setColor(this.progressBar.getForeground());
        if (this.progressBar.getOrientation() == 0) {
            if (cellSpacing == 0 && amountFull > 0) {
                graphics2D.setStroke(new BasicStroke((float)n2, 0, 2));
            }
            else {
                graphics2D.setStroke(new BasicStroke((float)n2, 0, 2, 0.0f, new float[] { (float)cellLength, (float)cellSpacing }, 0.0f));
            }
            if (BasicGraphicsUtils.isLeftToRight(component)) {
                graphics2D.drawLine(insets.left, n2 / 2 + insets.top, amountFull + insets.left, n2 / 2 + insets.top);
            }
            else {
                graphics2D.drawLine(n + insets.left, n2 / 2 + insets.top, n + insets.left - amountFull, n2 / 2 + insets.top);
            }
        }
        else {
            if (cellSpacing == 0 && amountFull > 0) {
                graphics2D.setStroke(new BasicStroke((float)n, 0, 2));
            }
            else {
                graphics2D.setStroke(new BasicStroke((float)n, 0, 2, 0.0f, new float[] { (float)cellLength, (float)cellSpacing }, 0.0f));
            }
            graphics2D.drawLine(n / 2 + insets.left, insets.top + n2, n / 2 + insets.left, insets.top + n2 - amountFull);
        }
        if (this.progressBar.isStringPainted()) {
            this.paintString(graphics, insets.left, insets.top, n, n2, amountFull, insets);
        }
        return;
    }
    
    protected void paintString(Graphics graphics, int n, int n2, int n3, int n4, int n5, Insets insets) {
        if (this.progressBar.getOrientation() == 0) {
            if (BasicGraphicsUtils.isLeftToRight(this.progressBar)) {
                if (this.progressBar.isIndeterminate()) {
                    this.boxRect = this.getBox(this.boxRect);
                    this.paintString(graphics, n, n2, n3, n4, this.boxRect.x, this.boxRect.width, insets);
                }
                else {
                    this.paintString(graphics, n, n2, n3, n4, n, n5, insets);
                }
            }
            else {
                this.paintString(graphics, n, n2, n3, n4, n + n3 - n5, n5, insets);
            }
        }
        else if (this.progressBar.isIndeterminate()) {
            this.boxRect = this.getBox(this.boxRect);
            this.paintString(graphics, n, n2, n3, n4, this.boxRect.y, this.boxRect.height, insets);
        }
        else {
            this.paintString(graphics, n, n2, n3, n4, n2 + n4 - n5, n5, insets);
        }
    }
    
    private void paintString(Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6, Insets insets) {
        if (!(graphics instanceof Graphics2D)) {
            return;
        }
        Graphics2D graphics2D = (Graphics2D)graphics;
        String string = this.progressBar.getString();
        graphics2D.setFont(this.progressBar.getFont());
        Point stringPlacement = this.getStringPlacement(graphics2D, string, n, n2, n3, n4);
        Rectangle clipBounds = graphics2D.getClipBounds();
        if (this.progressBar.getOrientation() == 0) {
            graphics2D.setColor(this.getSelectionBackground());
            SwingUtilities2.drawString(this.progressBar, graphics2D, string, stringPlacement.x, stringPlacement.y);
            graphics2D.setColor(this.getSelectionForeground());
            graphics2D.clipRect(n5, n2, n6, n4);
            SwingUtilities2.drawString(this.progressBar, graphics2D, string, stringPlacement.x, stringPlacement.y);
        }
        else {
            graphics2D.setColor(this.getSelectionBackground());
            graphics2D.setFont(this.progressBar.getFont().deriveFont(AffineTransform.getRotateInstance(1.5707963267948966)));
            Point stringPlacement2 = this.getStringPlacement(graphics2D, string, n, n2, n3, n4);
            SwingUtilities2.drawString(this.progressBar, graphics2D, string, stringPlacement2.x, stringPlacement2.y);
            graphics2D.setColor(this.getSelectionForeground());
            graphics2D.clipRect(n, n5, n3, n6);
            SwingUtilities2.drawString(this.progressBar, graphics2D, string, stringPlacement2.x, stringPlacement2.y);
        }
        graphics2D.setClip(clipBounds);
        return;
    }
    
    protected Point getStringPlacement(Graphics g, String string, int n, int n2, int n3, int n4) {
        FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(this.progressBar, g, this.progressBar.getFont());
        int stringWidth = SwingUtilities2.stringWidth(this.progressBar, fontMetrics, string);
        if (this.progressBar.getOrientation() == 0) {
            return new Point(n + Math.round((float)(n3 / 2 - stringWidth / 2)), n2 + (n4 + fontMetrics.getAscent() - fontMetrics.getLeading() - fontMetrics.getDescent()) / 2);
        }
        return new Point(n + (n3 - fontMetrics.getAscent() + fontMetrics.getLeading() + fontMetrics.getDescent()) / 2, n2 + Math.round((float)(n4 / 2 - stringWidth / 2)));
    }
    
    @Override
    public Dimension getPreferredSize(JComponent component) {
        Insets insets = this.progressBar.getInsets();
        FontMetrics fontMetrics = this.progressBar.getFontMetrics(this.progressBar.getFont());
        Dimension dimension;
        if (this.progressBar.getOrientation() == 0) {
            dimension = new Dimension(this.getPreferredInnerHorizontal());
            if (this.progressBar.isStringPainted()) {
                int stringWidth2 = SwingUtilities2.stringWidth(this.progressBar, fontMetrics, this.progressBar.getString());
                if (stringWidth2 > dimension.width) {
                    dimension.width = stringWidth2;
                }
                int height = fontMetrics.getHeight() + fontMetrics.getDescent();
                if (height > dimension.height) {
                    dimension.height = height;
                }
            }
        }
        else {
            dimension = new Dimension(this.getPreferredInnerVertical());
            if (this.progressBar.isStringPainted()) {
                String string = this.progressBar.getString();
                int width = fontMetrics.getHeight() + fontMetrics.getDescent();
                if (width > dimension.width) {
                    dimension.width = width;
                }
                int stringWidth = SwingUtilities2.stringWidth(this.progressBar, fontMetrics, string);
                if (stringWidth > dimension.height) {
                    dimension.height = stringWidth;
                }
            }
        }
        dimension.width += insets.left + insets.right;
        dimension.height += insets.top + insets.bottom;
        return dimension;
    }
    
    @Override
    public Dimension getMinimumSize(JComponent component) {
        Dimension preferredSize = this.getPreferredSize(this.progressBar);
        if (this.progressBar.getOrientation() == 0) {
            preferredSize.width = 10;
            return preferredSize;
        }
        preferredSize.height = 10;
        return preferredSize;
    }
    
    @Override
    public Dimension getMaximumSize(JComponent component) {
        Dimension preferredSize = this.getPreferredSize(this.progressBar);
        if (this.progressBar.getOrientation() == 0) {
            preferredSize.width = 32767;
            return preferredSize;
        }
        preferredSize.height = 32767;
        return preferredSize;
    }
    
    protected int getAnimationIndex() {
        return this.animationIndex;
    }
    
    protected final int getFrameCount() {
        return this.numFrames;
    }
    
    protected void setAnimationIndex(int n) {
        if (this.animationIndex != n) {
            if (this.sizeChanged()) {
                this.animationIndex = n;
                this.maxPosition = 0;
                this.delta = 0.0;
                this.progressBar.repaint();
                return;
            }
            this.nextPaintRect = this.getBox(this.nextPaintRect);
            this.animationIndex = n;
            if (this.nextPaintRect != null) {
                this.boxRect = this.getBox(this.boxRect);
                if (this.boxRect != null) {
                    this.nextPaintRect.add(this.boxRect);
                }
            }
            if (this.nextPaintRect != null) {
                this.progressBar.repaint(this.nextPaintRect);
            }
            else {
                this.progressBar.repaint();
            }
            return;
        }
        else {
            return;
        }
    }
    
    private boolean sizeChanged() {
        if (this.oldComponentInnards == null || this.componentInnards == null) {
            return true;
        }
        this.oldComponentInnards.setRect(this.componentInnards);
        this.componentInnards = SwingUtilities.calculateInnerArea(this.progressBar, this.componentInnards);
        return !this.oldComponentInnards.equals(this.componentInnards);
    }
    
    protected void incrementAnimationIndex() {
        int animationIndex = this.getAnimationIndex() + 1;
        if (animationIndex < this.numFrames) {
            this.setAnimationIndex(animationIndex);
        }
        else {
            this.setAnimationIndex(0);
        }
    }
    
    private int getRepaintInterval() {
        return this.repaintInterval;
    }
    
    private int initRepaintInterval() {
        return this.repaintInterval = DefaultLookup.getInt(this.progressBar, this, "ProgressBar.repaintInterval", 50);
    }
    
    private int getCycleTime() {
        return this.cycleTime;
    }
    
    private int initCycleTime() {
        return this.cycleTime = DefaultLookup.getInt(this.progressBar, this, "ProgressBar.cycleTime", 3000);
    }
    
    private void initIndeterminateDefaults() {
        this.initRepaintInterval();
        this.initCycleTime();
        if (this.repaintInterval <= 0) {
            this.repaintInterval = 100;
        }
        if (this.repaintInterval > this.cycleTime) {
            this.cycleTime = this.repaintInterval * 20;
        }
        else {
            this.cycleTime = this.repaintInterval * (int)Math.ceil((double)this.cycleTime / ((double)this.repaintInterval * 2.0)) * 2;
        }
    }
    
    private void initIndeterminateValues() {
        this.initIndeterminateDefaults();
        this.numFrames = this.cycleTime / this.repaintInterval;
        this.initAnimationIndex();
        this.boxRect = new Rectangle();
        this.nextPaintRect = new Rectangle();
        this.componentInnards = new Rectangle();
        this.oldComponentInnards = new Rectangle();
        this.progressBar.addHierarchyListener(this.getHandler());
        if (this.progressBar.isDisplayable()) {
            this.startAnimationTimer();
        }
    }
    
    private void cleanUpIndeterminateValues() {
        if (this.progressBar.isDisplayable()) {
            this.stopAnimationTimer();
        }
        int n = 0;
        this.repaintInterval = n;
        this.cycleTime = n;
        int n2 = 0;
        this.animationIndex = n2;
        this.numFrames = n2;
        this.maxPosition = 0;
        this.delta = 0.0;
        Rectangle rectangle = null;
        this.nextPaintRect = rectangle;
        this.boxRect = rectangle;
        Rectangle rectangle2 = null;
        this.oldComponentInnards = rectangle2;
        this.componentInnards = rectangle2;
        this.progressBar.removeHierarchyListener(this.getHandler());
    }
    
    private void initAnimationIndex() {
        if (this.progressBar.getOrientation() == 0 && BasicGraphicsUtils.isLeftToRight(this.progressBar)) {
            this.setAnimationIndex(0);
        }
        else {
            this.setAnimationIndex(this.numFrames / 2);
        }
    }
    
    static int access$500(BasicProgressBarUI basicProgressBarUI) {
        return basicProgressBarUI.getRepaintInterval();
    }
    
    static BasicProgressBarUI.Handler access$600(BasicProgressBarUI basicProgressBarUI) {
        return basicProgressBarUI.getHandler();
    }
    
    static int access$700(BasicProgressBarUI basicProgressBarUI) {
        return basicProgressBarUI.getCachedPercent();
    }
    
    static void access$800(BasicProgressBarUI basicProgressBarUI, int cachedPercent) {
        basicProgressBarUI.setCachedPercent(cachedPercent);
    }
    
    static void access$900(BasicProgressBarUI basicProgressBarUI) {
        basicProgressBarUI.initIndeterminateValues();
    }
    
    static void access$1000(BasicProgressBarUI basicProgressBarUI) {
        basicProgressBarUI.cleanUpIndeterminateValues();
    }
    
    static {
        BasicProgressBarUI.ADJUSTTIMER = true;
    }
    
    private class Animator implements ActionListener
    {
        private Timer timer;
        private long previousDelay;
        private int interval;
        private long lastCall;
        private int MINIMUM_DELAY;
        
        private Animator() {
            this.MINIMUM_DELAY = 5;
        }
        
        private void start(int n) {
            this.previousDelay = (long)n;
            this.lastCall = 0L;
            if (this.timer == null) {
                this.timer = new Timer(n, this);
            }
            else {
                this.timer.setDelay(n);
            }
            if (BasicProgressBarUI.ADJUSTTIMER) {
                this.timer.setRepeats(false);
                this.timer.setCoalesce(false);
            }
            this.timer.start();
        }
        
        private void stop() {
            this.timer.stop();
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            if (BasicProgressBarUI.ADJUSTTIMER) {
                long currentTimeMillis = System.currentTimeMillis();
                if (this.lastCall > 0L) {
                    int minimum_DELAY = (int)(this.previousDelay - currentTimeMillis + this.lastCall + (long)BasicProgressBarUI.access$500(BasicProgressBarUI.this));
                    if (minimum_DELAY < this.MINIMUM_DELAY) {
                        minimum_DELAY = this.MINIMUM_DELAY;
                    }
                    this.timer.setInitialDelay(minimum_DELAY);
                    this.previousDelay = (long)minimum_DELAY;
                }
                this.timer.start();
                this.lastCall = currentTimeMillis;
            }
            BasicProgressBarUI.this.incrementAnimationIndex();
        }
        
        static void access$200(BasicProgressBarUI.Animator animator, int n) {
            animator.start(n);
        }
        
        static void access$300(BasicProgressBarUI.Animator animator) {
            animator.stop();
        }
    }
    
    public class ChangeHandler implements ChangeListener
    {
        @Override
        public void stateChanged(ChangeEvent changeEvent) {
            BasicProgressBarUI.access$600(BasicProgressBarUI.this).stateChanged(changeEvent);
        }
    }
    
    private class Handler implements ChangeListener, PropertyChangeListener, HierarchyListener
    {
        @Override
        public void stateChanged(ChangeEvent changeEvent) {
            BoundedRangeModel model = BasicProgressBarUI.this.progressBar.getModel();
            int n = model.getMaximum() - model.getMinimum();
            int access$700 = BasicProgressBarUI.access$700(BasicProgressBarUI.this);
            int n2;
            if (n > 0) {
                n2 = (int)(100L * (long)model.getValue() / (long)n);
            }
            else {
                n2 = 0;
            }
            if (n2 != access$700) {
                BasicProgressBarUI.access$800(BasicProgressBarUI.this, n2);
                BasicProgressBarUI.this.progressBar.repaint();
            }
        }
        
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            if ("indeterminate" == propertyChangeEvent.getPropertyName()) {
                if (BasicProgressBarUI.this.progressBar.isIndeterminate()) {
                    BasicProgressBarUI.access$900(BasicProgressBarUI.this);
                }
                else {
                    BasicProgressBarUI.access$1000(BasicProgressBarUI.this);
                }
                BasicProgressBarUI.this.progressBar.repaint();
            }
        }
        
        @Override
        public void hierarchyChanged(HierarchyEvent hierarchyEvent) {
            if ((hierarchyEvent.getChangeFlags() & 0x2L) != 0x0L && BasicProgressBarUI.this.progressBar.isIndeterminate()) {
                if (BasicProgressBarUI.this.progressBar.isDisplayable()) {
                    BasicProgressBarUI.this.startAnimationTimer();
                }
                else {
                    BasicProgressBarUI.this.stopAnimationTimer();
                }
            }
        }
    }
}
